#[repr(C)]pub struct Camera {
pub projection: Mat4,
pub view: Mat4,
pub position: Vec3,
}Expand description
A camera used for transforming the stage during rendering.
Use Camera::new to create a new camera.
Or use Camera::default followed by Camera::with_projection_and_view
to set the projection and view matrices. Using the with_* or set_*
methods is preferred over setting the fields directly because they will
also update the cameraโs position.
Fields
projection: Mat4view: Mat4position: Vec3Implementations
Sourceimpl Camera
impl Camera
pub fn new(projection: Mat4, view: Mat4) -> Self
pub fn default_perspective(width: f32, height: f32) -> Self
pub fn default_ortho2d(width: f32, height: f32) -> Self
pub fn set_projection_and_view(&mut self, projection: Mat4, view: Mat4)
pub fn with_projection_and_view(self, projection: Mat4, view: Mat4) -> Self
pub fn set_projection(&mut self, projection: Mat4)
pub fn with_projection(self, projection: Mat4) -> Self
pub fn set_view(&mut self, view: Mat4)
pub fn with_view(self, view: Mat4) -> Self