Vec4

Struct Vec4 

#[repr(C, align(16))]
pub struct Vec4 { pub x: f32, pub y: f32, pub z: f32, pub w: f32, }
A 4-dimensional vector.

Fields

x: f32y: f32z: f32w: f32

Implementations

Source

impl Vec4

pub const ZERO: Vec4

All zeroes.

pub const ONE: Vec4

All ones.

pub const NEG_ONE: Vec4

All negative ones.

pub const MIN: Vec4

All f32::MIN.

pub const MAX: Vec4

All f32::MAX.

pub const NAN: Vec4

All f32::NAN.

pub const INFINITY: Vec4

All f32::INFINITY.

pub const NEG_INFINITY: Vec4

All f32::NEG_INFINITY.

pub const X: Vec4

A unit vector pointing along the positive X axis.

pub const Y: Vec4

A unit vector pointing along the positive Y axis.

pub const Z: Vec4

A unit vector pointing along the positive Z axis.

pub const W: Vec4

A unit vector pointing along the positive W axis.

pub const NEG_X: Vec4

A unit vector pointing along the negative X axis.

pub const NEG_Y: Vec4

A unit vector pointing along the negative Y axis.

pub const NEG_Z: Vec4

A unit vector pointing along the negative Z axis.

pub const NEG_W: Vec4

A unit vector pointing along the negative W axis.

pub const AXES: [Vec4; 4]

The unit axes.

pub const fn new(x: f32, y: f32, z: f32, w: f32) -> Vec4

Creates a new vector.

pub const fn splat(v: f32) -> Vec4

Creates a vector with all elements set to v.

pub fn select(mask: BVec4, if_true: Vec4, if_false: Vec4) -> Vec4

Creates a vector from the elements in if_true and if_false, selecting which to use for each element of self.

A true element in the mask uses the corresponding element from if_true, and false uses the element from if_false.

pub const fn from_array(a: [f32; 4]) -> Vec4

Creates a new vector from an array.

pub const fn to_array(&self) -> [f32; 4]

[x, y, z, w]

pub const fn from_slice(slice: &[f32]) -> Vec4

Creates a vector from the first 4 values in slice.

Panics

Panics if slice is less than 4 elements long.

pub fn write_to_slice(self, slice: &mut [f32])

Writes the elements of self to the first 4 elements in slice.

Panics

Panics if slice is less than 4 elements long.

pub fn truncate(self) -> Vec3

Creates a 3D vector from the x, y and z elements of self, discarding w.

Truncation to Vec3 may also be performed by using self.xyz().

To truncate to Vec3A use Vec3A::from().

pub fn dot(self, rhs: Vec4) -> f32

Computes the dot product of self and rhs.

pub fn dot_into_vec(self, rhs: Vec4) -> Vec4

Returns a vector where every component is the dot product of self and rhs.

pub fn min(self, rhs: Vec4) -> Vec4

Returns a vector containing the minimum values for each element of self and rhs.

In other words this computes [self.x.min(rhs.x), self.y.min(rhs.y), ..].

pub fn max(self, rhs: Vec4) -> Vec4

Returns a vector containing the maximum values for each element of self and rhs.

In other words this computes [self.x.max(rhs.x), self.y.max(rhs.y), ..].

pub fn clamp(self, min: Vec4, max: Vec4) -> Vec4

Component-wise clamping of values, similar to f32::clamp.

Each element in min must be less-or-equal to the corresponding element in max.

Panics

Will panic if min is greater than max when glam_assert is enabled.

pub fn min_element(self) -> f32

Returns the horizontal minimum of self.

In other words this computes min(x, y, ..).

pub fn max_element(self) -> f32

Returns the horizontal maximum of self.

In other words this computes max(x, y, ..).

pub fn cmpeq(self, rhs: Vec4) -> BVec4

Returns a vector mask containing the result of a == comparison for each element of self and rhs.

In other words, this computes [self.x == rhs.x, self.y == rhs.y, ..] for all elements.

pub fn cmpne(self, rhs: Vec4) -> BVec4

Returns a vector mask containing the result of a != comparison for each element of self and rhs.

In other words this computes [self.x != rhs.x, self.y != rhs.y, ..] for all elements.

pub fn cmpge(self, rhs: Vec4) -> BVec4

Returns a vector mask containing the result of a >= comparison for each element of self and rhs.

In other words this computes [self.x >= rhs.x, self.y >= rhs.y, ..] for all elements.

pub fn cmpgt(self, rhs: Vec4) -> BVec4

Returns a vector mask containing the result of a > comparison for each element of self and rhs.

In other words this computes [self.x > rhs.x, self.y > rhs.y, ..] for all elements.

pub fn cmple(self, rhs: Vec4) -> BVec4

Returns a vector mask containing the result of a <= comparison for each element of self and rhs.

In other words this computes [self.x <= rhs.x, self.y <= rhs.y, ..] for all elements.

pub fn cmplt(self, rhs: Vec4) -> BVec4

Returns a vector mask containing the result of a < comparison for each element of self and rhs.

In other words this computes [self.x < rhs.x, self.y < rhs.y, ..] for all elements.

pub fn abs(self) -> Vec4

Returns a vector containing the absolute value of each element of self.

pub fn signum(self) -> Vec4

Returns a vector with elements representing the sign of self.

  • 1.0 if the number is positive, +0.0 or INFINITY
  • -1.0 if the number is negative, -0.0 or NEG_INFINITY
  • NAN if the number is NAN
pub fn copysign(self, rhs: Vec4) -> Vec4

Returns a vector with signs of rhs and the magnitudes of self.

pub fn is_negative_bitmask(self) -> u32

Returns a bitmask with the lowest 4 bits set to the sign bits from the elements of self.

A negative element results in a 1 bit and a positive element in a 0 bit. Element x goes into the first lowest bit, element y into the second, etc.

pub fn is_finite(self) -> bool

Returns true if, and only if, all elements are finite. If any element is either NaN, positive or negative infinity, this will return false.

pub fn is_nan(self) -> bool

Returns true if any elements are NaN.

pub fn is_nan_mask(self) -> BVec4

Performs is_nan on each element of self, returning a vector mask of the results.

In other words, this computes [x.is_nan(), y.is_nan(), z.is_nan(), w.is_nan()].

pub fn length(self) -> f32

Computes the length of self.

pub fn length_squared(self) -> f32

Computes the squared length of self.

This is faster than length() as it avoids a square root operation.

pub fn length_recip(self) -> f32

Computes 1.0 / length().

For valid results, self must not be of length zero.

pub fn distance(self, rhs: Vec4) -> f32

Computes the Euclidean distance between two points in space.

pub fn distance_squared(self, rhs: Vec4) -> f32

Compute the squared euclidean distance between two points in space.

pub fn div_euclid(self, rhs: Vec4) -> Vec4

Returns the element-wise quotient of [Euclidean division] of self by rhs.

pub fn rem_euclid(self, rhs: Vec4) -> Vec4

Returns the element-wise remainder of Euclidean division of self by rhs.

pub fn normalize(self) -> Vec4

Returns self normalized to length 1.0.

For valid results, self must not be of length zero, nor very close to zero.

See also Self::try_normalize() and Self::normalize_or_zero().

Panics

Will panic if self is zero length when glam_assert is enabled.

pub fn try_normalize(self) -> Option<Vec4>

Returns self normalized to length 1.0 if possible, else returns None.

In particular, if the input is zero (or very close to zero), or non-finite, the result of this operation will be None.

See also Self::normalize_or_zero().

pub fn normalize_or_zero(self) -> Vec4

Returns self normalized to length 1.0 if possible, else returns zero.

In particular, if the input is zero (or very close to zero), or non-finite, the result of this operation will be zero.

See also Self::try_normalize().

pub fn is_normalized(self) -> bool

Returns whether self is length 1.0 or not.

Uses a precision threshold of 1e-6.

pub fn project_onto(self, rhs: Vec4) -> Vec4

Returns the vector projection of self onto rhs.

rhs must be of non-zero length.

Panics

Will panic if rhs is zero length when glam_assert is enabled.

pub fn reject_from(self, rhs: Vec4) -> Vec4

Returns the vector rejection of self from rhs.

The vector rejection is the vector perpendicular to the projection of self onto rhs, in rhs words the result of self - self.project_onto(rhs).

rhs must be of non-zero length.

Panics

Will panic if rhs has a length of zero when glam_assert is enabled.

pub fn project_onto_normalized(self, rhs: Vec4) -> Vec4

Returns the vector projection of self onto rhs.

rhs must be normalized.

Panics

Will panic if rhs is not normalized when glam_assert is enabled.

pub fn reject_from_normalized(self, rhs: Vec4) -> Vec4

Returns the vector rejection of self from rhs.

The vector rejection is the vector perpendicular to the projection of self onto rhs, in rhs words the result of self - self.project_onto(rhs).

rhs must be normalized.

Panics

Will panic if rhs is not normalized when glam_assert is enabled.

pub fn round(self) -> Vec4

Returns a vector containing the nearest integer to a number for each element of self. Round half-way cases away from 0.0.

pub fn floor(self) -> Vec4

Returns a vector containing the largest integer less than or equal to a number for each element of self.

pub fn ceil(self) -> Vec4

Returns a vector containing the smallest integer greater than or equal to a number for each element of self.

pub fn trunc(self) -> Vec4

Returns a vector containing the integer part each element of self. This means numbers are always truncated towards zero.

pub fn fract(self) -> Vec4

Returns a vector containing the fractional part of the vector, e.g. self - self.floor().

Note that this is fast but not precise for large numbers.

pub fn exp(self) -> Vec4

Returns a vector containing e^self (the exponential function) for each element of self.

pub fn powf(self, n: f32) -> Vec4

Returns a vector containing each element of self raised to the power of n.

pub fn recip(self) -> Vec4

Returns a vector containing the reciprocal 1.0/n of each element of self.

pub fn lerp(self, rhs: Vec4, s: f32) -> Vec4

Performs a linear interpolation between self and rhs based on the value s.

When s is 0.0, the result will be equal to self. When s is 1.0, the result will be equal to rhs. When s is outside of range [0, 1], the result is linearly extrapolated.

pub fn abs_diff_eq(self, rhs: Vec4, max_abs_diff: f32) -> bool

Returns true if the absolute difference of all elements between self and rhs is less than or equal to max_abs_diff.

This can be used to compare if two vectors contain similar elements. It works best when comparing with a known value. The max_abs_diff that should be used used depends on the values being compared against.

For more see comparing floating point numbers.

pub fn clamp_length(self, min: f32, max: f32) -> Vec4

Returns a vector with a length no less than min and no more than max

Panics

Will panic if min is greater than max when glam_assert is enabled.

pub fn clamp_length_max(self, max: f32) -> Vec4

Returns a vector with a length no more than max

pub fn clamp_length_min(self, min: f32) -> Vec4

Returns a vector with a length no less than min

pub fn mul_add(self, a: Vec4, b: Vec4) -> Vec4

Fused multiply-add. Computes (self * a) + b element-wise with only one rounding error, yielding a more accurate result than an unfused multiply-add.

Using mul_add may be more performant than an unfused multiply-add if the target architecture has a dedicated fma CPU instruction. However, this is not always true, and will be heavily dependant on designing algorithms with specific target hardware in mind.

pub fn as_dvec4(&self) -> DVec4

Casts all elements of self to f64.

pub fn as_ivec4(&self) -> IVec4

Casts all elements of self to i32.

pub fn as_uvec4(&self) -> UVec4

Casts all elements of self to u32.

pub fn as_i64vec4(&self) -> I64Vec4

Casts all elements of self to i64.

pub fn as_u64vec4(&self) -> U64Vec4

Casts all elements of self to u64.