DMat2

Struct DMat2 

#[repr(C)]
pub struct DMat2 { pub x_axis: DVec2, pub y_axis: DVec2, }
A 2x2 column major matrix.

Fields

x_axis: DVec2y_axis: DVec2

Implementations

Source

impl DMat2

pub const ZERO: DMat2

A 2x2 matrix with all elements set to 0.0.

pub const IDENTITY: DMat2

A 2x2 identity matrix, where all diagonal elements are 1, and all off-diagonal elements are 0.

pub const NAN: DMat2

All NAN:s.

pub const fn from_cols(x_axis: DVec2, y_axis: DVec2) -> DMat2

Creates a 2x2 matrix from two column vectors.

pub const fn from_cols_array(m: &[f64; 4]) -> DMat2

Creates a 2x2 matrix from a [f64; 4] array stored in column major order. If your data is stored in row major you will need to transpose the returned matrix.

pub const fn to_cols_array(&self) -> [f64; 4]

Creates a [f64; 4] array storing data in column major order. If you require data in row major order transpose the matrix first.

pub const fn from_cols_array_2d(m: &[[f64; 2]; 2]) -> DMat2

Creates a 2x2 matrix from a [[f64; 2]; 2] 2D array stored in column major order. If your data is in row major order you will need to transpose the returned matrix.

pub const fn to_cols_array_2d(&self) -> [[f64; 2]; 2]

Creates a [[f64; 2]; 2] 2D array storing data in column major order. If you require data in row major order transpose the matrix first.

pub const fn from_diagonal(diagonal: DVec2) -> DMat2

Creates a 2x2 matrix with its diagonal set to diagonal and all other entries set to 0.

pub fn from_scale_angle(scale: DVec2, angle: f64) -> DMat2

Creates a 2x2 matrix containing the combining non-uniform scale and rotation of angle (in radians).

pub fn from_angle(angle: f64) -> DMat2

Creates a 2x2 matrix containing a rotation of angle (in radians).

pub fn from_mat3(m: DMat3) -> DMat2

Creates a 2x2 matrix from a 3x3 matrix, discarding the 2nd row and column.

pub const fn from_cols_slice(slice: &[f64]) -> DMat2

Creates a 2x2 matrix from the first 4 values in slice.

Panics

Panics if slice is less than 4 elements long.

pub fn write_cols_to_slice(self, slice: &mut [f64])

Writes the columns of self to the first 4 elements in slice.

Panics

Panics if slice is less than 4 elements long.

pub fn col(&self, index: usize) -> DVec2

Returns the matrix column for the given index.

Panics

Panics if index is greater than 1.

pub fn col_mut(&mut self, index: usize) -> &mut DVec2

Returns a mutable reference to the matrix column for the given index.

Panics

Panics if index is greater than 1.

pub fn row(&self, index: usize) -> DVec2

Returns the matrix row for the given index.

Panics

Panics if index is greater than 1.

pub fn is_finite(&self) -> bool

Returns true if, and only if, all elements are finite. If any element is either NaN, positive or negative infinity, this will return false.

pub fn is_nan(&self) -> bool

Returns true if any elements are NaN.

pub fn transpose(&self) -> DMat2

Returns the transpose of self.

pub fn determinant(&self) -> f64

Returns the determinant of self.

pub fn inverse(&self) -> DMat2

Returns the inverse of self.

If the matrix is not invertible the returned matrix will be invalid.

Panics

Will panic if the determinant of self is zero when glam_assert is enabled.

pub fn mul_vec2(&self, rhs: DVec2) -> DVec2

Transforms a 2D vector.

pub fn mul_mat2(&self, rhs: &DMat2) -> DMat2

Multiplies two 2x2 matrices.

pub fn add_mat2(&self, rhs: &DMat2) -> DMat2

Adds two 2x2 matrices.

pub fn sub_mat2(&self, rhs: &DMat2) -> DMat2

Subtracts two 2x2 matrices.

pub fn mul_scalar(&self, rhs: f64) -> DMat2

Multiplies a 2x2 matrix by a scalar.

pub fn abs_diff_eq(&self, rhs: DMat2, max_abs_diff: f64) -> bool

Returns true if the absolute difference of all elements between self and rhs is less than or equal to max_abs_diff.

This can be used to compare if two matrices contain similar elements. It works best when comparing with a known value. The max_abs_diff that should be used used depends on the values being compared against.

For more see comparing floating point numbers.

pub fn as_mat2(&self) -> Mat2