UpdatesSlab

Trait UpdatesSlab 

pub trait UpdatesSlab:
    Send
    + Sync
    + Any {
    // Required methods
    fn id(&self) -> usize;
    fn u32_array(&self) -> Array<u32>;
    fn strong_count(&self) -> usize;
    fn get_update(&self) -> Vec<SlabUpdate>;
}

Required Methods

fn id(&self) -> usize

Return the id of this update source.

fn u32_array(&self) -> Array<u32>

Returns the slab range of all possible updates.

fn strong_count(&self) -> usize

Returns the number of references remaining in the wild.

fn get_update(&self) -> Vec<SlabUpdate>

Return the latest update, if any.

Warning!

This will likely clear the update from its queue.

Implementors