pub struct Tween {
pub keyframes: Vec<Keyframe>,
pub properties: TweenProperties,
pub interpolation: Interpolation,
pub target_node_index: usize,
}Fields
keyframes: Vec<Keyframe>properties: TweenPropertiesinterpolation: Interpolationtarget_node_index: usizeImplementations
Sourceimpl Tween
impl Tween
Sourcepub fn interpolate(
&self,
time: f32,
) -> Result<Option<TweenProperty>, InterpolationError>
pub fn interpolate( &self, time: f32, ) -> Result<Option<TweenProperty>, InterpolationError>
Compute the interpolated tween property at the given time.
If the given time is before the first keyframe or after the the last
keyframe, Ok(None) is returned.
Sourcepub fn interpolate_wrap(
&self,
time: f32,
) -> Result<Option<TweenProperty>, InterpolationError>
pub fn interpolate_wrap( &self, time: f32, ) -> Result<Option<TweenProperty>, InterpolationError>
Compute the interpolated tween property at the given time.
If the time is greater than the last keyframe, the time will be wrapped to loop the tween.
Returns None if the properties don’t match.
pub fn length_in_seconds(&self) -> f32
pub fn get_first_keyframe_property(&self) -> Option<TweenProperty>
pub fn get_last_keyframe_property(&self) -> Option<TweenProperty>