pub struct RenderTarget(/* private fields */);Expand description
Either a surface or a texture.
Will be a surface if the context was created with a window or canvas.
Will be a texture if the context is headless.
Implementations