Texture

Struct Texture 

pub struct Texture {
    pub texture: Arc<Texture>,
    pub view: Arc<TextureView>,
    pub sampler: Arc<Sampler>,
}
A texture living on the GPU.

Fields

texture: Arc<Texture>view: Arc<TextureView>sampler: Arc<Sampler>

Implementations

Source

impl Texture

pub const DEPTH_FORMAT: TextureFormat = wgpu::TextureFormat::Depth32Float

pub const HDR_TEXTURE_FORMAT: TextureFormat = wgpu::TextureFormat::Rgba16Float

pub fn width(&self) -> u32

pub fn height(&self) -> u32

pub fn new_cubemap_texture( device: &Device, queue: &Queue, label: Option<&str>, texture_size: u32, face_textures: &[Texture], image_format: TextureFormat, mip_levels: u32, ) -> Self

Create a cubemap texture from 6 faces.

pub fn new_with( device: &Device, queue: &Queue, label: Option<&str>, usage: Option<TextureUsages>, sampler: Option<Sampler>, format: TextureFormat, color_channels: u32, color_channel_bytes: u32, width: u32, height: u32, mip_level_count: u32, data: &[u8], ) -> Self

Create a new texture.

pub fn new( device: &Device, queue: &Queue, label: Option<&str>, usage: Option<TextureUsages>, color_channels: u32, width: u32, height: u32, data: &[u8], ) -> Self

Create a new texture.

This defaults the format to Rgba8UnormSrgb and assumes a pixel is 1 byte per channel.

pub fn from_image_bytes( device: &Device, queue: &Queue, bytes: &[u8], label: &str, ) -> Result<Self, TextureError>

pub fn from_dynamic_image( device: &Device, queue: &Queue, dyn_img: DynamicImage, label: Option<&str>, usage: Option<TextureUsages>, mip_level_count: u32, ) -> Self

pub fn from_image_buffer<P>( device: &Device, queue: &Queue, img: &ImageBuffer<P, Vec<u8>>, label: Option<&str>, usage: Option<TextureUsages>, mip_level_count: Option<u32>, ) -> Result<Self, TextureError>
where P: PixelWithColorType, ImageBuffer<P, Vec<u8>>: GenericImage + Deref<Target = [u8]>,

pub fn from_wgpu_tex( device: &Device, texture: impl Into<Arc<Texture>>, sampler: Option<SamplerDescriptor<'_>>, mip_level_count: Option<u32>, ) -> Self

pub fn create_depth_texture( device: &Device, width: u32, height: u32, multisample_count: u32, ) -> Self

pub fn read( texture: &Texture, device: &Device, queue: &Queue, width: usize, height: usize, channels: usize, subpixel_bytes: usize, ) -> CopiedTextureBuffer

Read the texture from the GPU.

To read the texture you must provide the width, height, the number of color/alpha channels and the number of bytes in the underlying subpixel type (usually u8=1, u16=2 or f32=4).

pub fn read_from( texture: &Texture, device: &Device, queue: &Queue, width: usize, height: usize, channels: usize, subpixel_bytes: usize, mip_level: u32, origin: Option<Origin3d>, ) -> CopiedTextureBuffer

Read the texture from the GPU.

To read the texture you must provide the width, height, the number of color/alpha channels and the number of bytes in the underlying subpixel type (usually u8=1, u16=2 or f32=4).

pub fn read_hdr_image( &self, device: &Device, queue: &Queue, ) -> Result<Rgba32FImage, TextureError>

pub fn generate_mips( &mut self, device: &Device, queue: &Queue, label: Option<&str>, mip_levels: u32, ) -> Vec<Self>

Generate mipmap_levels - 1 mipmaps for the given texture.

Note

Ensure that self only has one mip level. If not it will try to sample from an empty mip.

pub fn create_hdr_texture( device: &Device, width: u32, height: u32, multisample_count: u32, ) -> Texture

Create a new HDR texture.