A tutorial module for the renderling crate.
Functions
- tutorial_
implicit_ isosceles_ vertex - Simple vertex shader with an implicit isosceles triangle.
- tutorial_
passthru_ fragment - Simple fragment shader that writes the input color to the output color.
- tutorial_
slabbed_ renderlet - This shader uses the
instance_indexas a slabId. Theinstance_indexis theIdof aRenderlet. TheRenderletcontains anArrayofVertexs as its mesh, theIds of aMaterialandCamera, and TRS transforms. Thevertex_indexis the index of aVertexwithin theRenderlet’sverticesArray. - tutorial_
slabbed_ vertices - This shader uses the
instance_indexas a slabId. Theinstance_indexis theIdof anArrayofVertexs. Thevertex_indexis the index of aVertexwithin theArray. - tutorial_
slabbed_ vertices_ no_ instance - This shader uses the vertex index as a slab
Id. TheIdis used to read the vertex from the slab. The vertex’s position and color are written to the output.