tutorial_slabbed_renderlet

Function tutorial_slabbed_renderlet 

pub fn tutorial_slabbed_renderlet(
    renderlet_id: Id<Renderlet>,
    vertex_index: u32,
    slab: &[u32],
    out_color: &mut Vec4,
    clip_pos: &mut Vec4,
)
This shader uses the instance_index as a slab Id. The instance_index is the Id of a Renderlet. The Renderlet contains an Array of Vertexs as its mesh, the Ids of a Material and Camera, and TRS transforms. The vertex_index is the index of a Vertex within the Renderlet’s vertices Array.