#[repr(C)]pub struct Affine2 {
pub matrix2: Mat2,
pub translation: Vec2,
}Expand description
A 2D affine transform, which can represent translation, rotation, scaling and shear.
Fields
matrix2: Mat2translation: Vec2Implementations
Sourceimpl Affine2
impl Affine2
Sourcepub const ZERO: Affine2
pub const ZERO: Affine2
The degenerate zero transform.
This transforms any finite vector and point to zero. The zero transform is non-invertible.
Sourcepub const IDENTITY: Affine2
pub const IDENTITY: Affine2
The identity transform.
Multiplying a vector with this returns the same vector.
Sourcepub const fn from_cols(x_axis: Vec2, y_axis: Vec2, z_axis: Vec2) -> Affine2
pub const fn from_cols(x_axis: Vec2, y_axis: Vec2, z_axis: Vec2) -> Affine2
Creates an affine transform from three column vectors.
Sourcepub fn from_cols_array(m: &[f32; 6]) -> Affine2
pub fn from_cols_array(m: &[f32; 6]) -> Affine2
Creates an affine transform from a [f32; 6] array stored in column major order.
Sourcepub fn to_cols_array(&self) -> [f32; 6]
pub fn to_cols_array(&self) -> [f32; 6]
Creates a [f32; 6] array storing data in column major order.
Sourcepub fn from_cols_array_2d(m: &[[f32; 2]; 3]) -> Affine2
pub fn from_cols_array_2d(m: &[[f32; 2]; 3]) -> Affine2
Creates an affine transform from a [[f32; 2]; 3]
2D array stored in column major order.
If your data is in row major order you will need to transpose the returned
matrix.
Sourcepub fn to_cols_array_2d(&self) -> [[f32; 2]; 3]
pub fn to_cols_array_2d(&self) -> [[f32; 2]; 3]
Creates a [[f32; 2]; 3] 2D array storing data in
column major order.
If you require data in row major order transpose the matrix first.
Sourcepub fn from_cols_slice(slice: &[f32]) -> Affine2
pub fn from_cols_slice(slice: &[f32]) -> Affine2
Creates an affine transform from the first 6 values in slice.
Panics
Panics if slice is less than 6 elements long.
Sourcepub fn write_cols_to_slice(self, slice: &mut [f32])
pub fn write_cols_to_slice(self, slice: &mut [f32])
Writes the columns of self to the first 6 elements in slice.
Panics
Panics if slice is less than 6 elements long.
Sourcepub fn from_scale(scale: Vec2) -> Affine2
pub fn from_scale(scale: Vec2) -> Affine2
Creates an affine transform that changes scale. Note that if any scale is zero the transform will be non-invertible.
Sourcepub fn from_angle(angle: f32) -> Affine2
pub fn from_angle(angle: f32) -> Affine2
Creates an affine transform from the given rotation angle.
Sourcepub fn from_translation(translation: Vec2) -> Affine2
pub fn from_translation(translation: Vec2) -> Affine2
Creates an affine transformation from the given 2D translation.
Sourcepub fn from_mat2(matrix2: Mat2) -> Affine2
pub fn from_mat2(matrix2: Mat2) -> Affine2
Creates an affine transform from a 2x2 matrix (expressing scale, shear and rotation)
Sourcepub fn from_mat2_translation(matrix2: Mat2, translation: Vec2) -> Affine2
pub fn from_mat2_translation(matrix2: Mat2, translation: Vec2) -> Affine2
Creates an affine transform from a 2x2 matrix (expressing scale, shear and rotation) and a translation vector.
Equivalent to
Affine2::from_translation(translation) * Affine2::from_mat2(mat2)
Sourcepub fn from_scale_angle_translation(
scale: Vec2,
angle: f32,
translation: Vec2,
) -> Affine2
pub fn from_scale_angle_translation( scale: Vec2, angle: f32, translation: Vec2, ) -> Affine2
Creates an affine transform from the given 2D scale, rotation angle (in radians) and
translation.
Equivalent to Affine2::from_translation(translation) * Affine2::from_angle(angle) * Affine2::from_scale(scale)
Sourcepub fn from_angle_translation(angle: f32, translation: Vec2) -> Affine2
pub fn from_angle_translation(angle: f32, translation: Vec2) -> Affine2
Creates an affine transform from the given 2D rotation angle (in radians) and
translation.
Equivalent to Affine2::from_translation(translation) * Affine2::from_angle(angle)
Sourcepub fn from_mat3a(m: Mat3A) -> Affine2
pub fn from_mat3a(m: Mat3A) -> Affine2
The given Mat3A must be an affine transform,
Sourcepub fn to_scale_angle_translation(self) -> (Vec2, f32, Vec2)
pub fn to_scale_angle_translation(self) -> (Vec2, f32, Vec2)
Extracts scale, angle and translation from self.
The transform is expected to be non-degenerate and without shearing, or the output will be invalid.
Panics
Will panic if the determinant self.matrix2 is zero or if the resulting scale
vector contains any zero elements when glam_assert is enabled.
Sourcepub fn transform_point2(&self, rhs: Vec2) -> Vec2
pub fn transform_point2(&self, rhs: Vec2) -> Vec2
Transforms the given 2D point, applying shear, scale, rotation and translation.
Sourcepub fn transform_vector2(&self, rhs: Vec2) -> Vec2
pub fn transform_vector2(&self, rhs: Vec2) -> Vec2
Transforms the given 2D vector, applying shear, scale and rotation (but NOT translation).
To also apply translation, use Self::transform_point2() instead.
Sourcepub fn is_finite(&self) -> bool
pub fn is_finite(&self) -> bool
Returns true if, and only if, all elements are finite.
If any element is either NaN, positive or negative infinity, this will return
false.
Sourcepub fn abs_diff_eq(&self, rhs: Affine2, max_abs_diff: f32) -> bool
pub fn abs_diff_eq(&self, rhs: Affine2, max_abs_diff: f32) -> bool
Returns true if the absolute difference of all elements between self and rhs
is less than or equal to max_abs_diff.
This can be used to compare if two 3x4 matrices contain similar elements. It works
best when comparing with a known value. The max_abs_diff that should be used used
depends on the values being compared against.
For more see comparing floating point numbers.